/******************************************************************************
*
* project name:    TI-Chess
* file name:       generic.c
* initial date:    13/07/2000
* authors:         thomas.nussbaumer@gmx.net (coding)
*                  marcos.lopez@gmx.net      (design/graphics/beta testing)
* description:     generic drawing routines
*
* $Id: generic.c,v 1.5 2002/02/11 16:38:11 tnussb Exp $
*
******************************************************************************/

#include "hardware.h"    // MUST BE ALWAYS HERE ON THE FIRST LINE !!!!
#include <graph.h>
#include <gray.h>

#include "generic.h"

SCR_RECT fullscreen = {{0, 0, 239, 127}}; // used for fullscreen clipping



/*===========================================================================*/
/* draw a line with given color from (x0,y0) to (x1,y1)                      */
/*===========================================================================*/
void DrawColorLine(short x0,short y0,short x1, short y1, short color) {
    SetPlane(LIGHT_PLANE);
    if (color == COLOR_WHITE || color == COLOR_DARKGRAY) {
        DrawLine(x0, y0, x1, y1, A_REVERSE);
    }
    else {
        DrawLine(x0, y0, x1, y1, A_NORMAL);
    }
    SetPlane(DARK_PLANE);
    if (color == COLOR_WHITE || color == COLOR_LIGHTGRAY) {
        DrawLine(x0, y0, x1, y1, A_REVERSE);
    }
    else {
        DrawLine(x0, y0, x1, y1, A_NORMAL);
    }
}



/*===========================================================================*/
/* draws a rectangle with given color                                        */
/* if fill == 1) the rectangle is filled                                     */
/*===========================================================================*/
void DrawColorRect(short x0,short y0,short x1, short y1, short color,short fill) {
    WIN_RECT wrect;
    SCR_RECT rect;
    void     (*df)(void*,void*,short);
    void*    parea;

    if (fill) {
        rect.xy.x0 = x0;
        rect.xy.y0 = y0;
        rect.xy.x1 = x1;
        rect.xy.y1 = y1;
        parea      = &rect;
        df         = (void(*)(void*,void*,short))ScrRectFill;
    }
    else {
        wrect.x0 = x0;
        wrect.y0 = y0;
        wrect.x1 = x1;
        wrect.y1 = y1;
        parea    = &wrect;
        df       = (void(*)(void*,void*,short))DrawClipRect;
    }

    SetPlane(LIGHT_PLANE);
    if (color == COLOR_WHITE || color == COLOR_DARKGRAY) {
        (*df)(parea,&fullscreen, A_REVERSE);
    }
    else {
        (*df)(parea,&fullscreen, A_NORMAL);
    }
    SetPlane(DARK_PLANE);
    if (color == COLOR_WHITE || color == COLOR_LIGHTGRAY) {
        (*df)(parea,&fullscreen, A_REVERSE);
    }
    else {
        (*df)(parea,&fullscreen, A_NORMAL);
    }
}



/*===========================================================================*/
/* invert a given area                                                       */
/*===========================================================================*/
void InvertGrayRect(short x0,short y0,short x1, short y1) {
    short p;
    SCR_RECT sr = {{x0,y0,x1,y1}};


    for (p=0;p<2;p++) {
        SetPlane(p);
        ScrRectFill(&sr,&fullscreen,A_XOR);
    }
}



/*===========================================================================*/
/* draws a popup window                                                      */
/*===========================================================================*/
void DrawPopup(short x0,short y0,short x1, short y1) {
    DrawColorRect(x0,y0,x1,y1,COLOR_BLACK,RECT_EMPTY);
    x0++,y0++,x1--,y1--;
    DrawColorRect(x0,y0,x1,y1,COLOR_DARKGRAY,RECT_EMPTY);
    x0++,y0++,x1--,y1--;
    DrawColorRect(x0,y0,x1,y1,COLOR_LIGHTGRAY,RECT_EMPTY);
    x0++,y0++,x1--,y1--;
    DrawColorRect(x0,y0,x1,y1,COLOR_WHITE,RECT_FILLED);
}



/*===========================================================================*/
/* utility funcction to draw a string to both planes                         */
/* NOTE: there exists to new styles which are handled as flags               */
/*       A_CENTERED ... the given font will be used and the string will be   */
/*                      drawn centered on the screen                         */
/*       A_SHADOWED ... if this flag is set in the attributes a lightgray    */
/*                      shadow will be drawn with +1 pixel offset in all     */
/*                      two directions                                       */
/*===========================================================================*/
void DrawString(short x,short y,const char* s,short font,short attr) {
    short do_shadow = attr & A_SHADOWED;

    FontSetSys(font);

    if (attr & A_CENTERED) {
        x = (STATIC_LCD_WIDTH-DrawStrWidth(s,font))/2;
        attr &= ~A_CENTERED;
    }

    attr &= ~A_SHADOWED;

    SetPlane(DARK_PLANE);
    DrawStr(x,y,s,attr);
    SetPlane(LIGHT_PLANE);
    DrawStr(x,y,s,attr);

    if (do_shadow) DrawStr(x+1,y+1,s,A_NORMAL);
}



//#############################################################################
//###################### NO MORE FAKES BEYOND THIS LINE #######################
//#############################################################################
//
//=============================================================================
// Revision History
//=============================================================================
//
// $Log: generic.c,v $
// Revision 1.5  2002/02/11 16:38:11  tnussb
// many changes due to "separate file compiling" restructuring
//
// Revision 1.4  2001/02/17 15:00:11  Thomas Nussbaumer
// changes due to new TIGCC version
//
// Revision 1.3  2000/12/19 13:55:29  Thomas Nussbaumer
// warnings stated by compiling with option -Wall fixed
//
// Revision 1.2  2000/08/12 15:31:12  Thomas Nussbaumer
// substitution keywords added
//
//
