/******************************************************************************
*
* project name:    TI-Chess
* file name:       routines.h
* initial date:    08/02/2002
* author:          thomas.nussbaumer@gmx.net
* description:     prototypes of routines which are shared between files
*
* $Id: routines.h,v 1.1 2002/02/11 16:34:23 tnussb Exp $
*
******************************************************************************/

#ifndef TICROUTINES_H
#define TICROUTINES_H

#include "defines.h"


//-----------------------------------------------------------------------------
// logo.c
//-----------------------------------------------------------------------------
void Logo(void);

//-----------------------------------------------------------------------------
// bg_ti89.c / bg_ti92.c
//-----------------------------------------------------------------------------
void OutputBackground();

//-----------------------------------------------------------------------------
// board.c
//-----------------------------------------------------------------------------
void DrawFigure(short x, short y,char s);
void DrawSquare(short x, short y,char s);
void DrawCoordinates(short inverted);

//-----------------------------------------------------------------------------
// clocks.c
//-----------------------------------------------------------------------------
void IncrementClock(void);
void SwitchClockPositions(void);
void ToggleClocks(short reset,short inverted);

//-----------------------------------------------------------------------------
// engine.c
//-----------------------------------------------------------------------------
void        FreeReservedMemory(void);
void        TakeBackMove(short silent);
void        UndoTakeBackMove(short silent);
short       InitMemory(void);
void        FreeMemory(void);
void        InitEngine(short level);
char*       Field2Notation(short fieldnumber,char* fieldnotation);
const char* Move2Str(move_t *pmove,short fromboard);
short       AttacksField(short field, short side);
void        InitPawnVars(void);
move_t*     ComputerMove(void);
short       UserMove(char* input,short updateboards);

//-----------------------------------------------------------------------------
// hash.c (but exported through engine.c -- for speedup reasons hash.c is
//         included in engine.c)
//-----------------------------------------------------------------------------
void ResetHashCounters(void);
void InitHashCode(void);
void CalcHashKey(void);


//-----------------------------------------------------------------------------
// generic.c
//-----------------------------------------------------------------------------
void DrawColorLine(short x0,short y0,short x1, short y1, short color);
void DrawColorRect(short x0,short y0,short x1, short y1, short color,short fill);
void InvertGrayRect(short x0,short y0,short x1, short y1);
void DrawPopup(short x0,short y0,short x1, short y1);
void DrawString(short x,short y,const char* s,short font,short attr);


//-----------------------------------------------------------------------------
// gui.c
//-----------------------------------------------------------------------------
short RequestDialog(const char* request);
void  LeavePrg(const char* msg);
void  CorrectInfoBoard(void);
void  MainGUI(void);


//-----------------------------------------------------------------------------
// infoboards.c
//-----------------------------------------------------------------------------
void DrawInfoBoard(short nr);
void UpdateMoveDisplay(move_t* pmove,short fromboard);
void UpdateNodeDisplay(long nodes);
void SetActiveInfo(short color,short level,short redraw);
void OutputSpecial(const char* s1,const char* s2);
void SwitchInfoBoards(void);
void ClearActiveInfoBoardData(void);
void ClearInfoBoardData(void);
void InitInfo(short color,short level1,short level2,short inverted);

//-----------------------------------------------------------------------------
// input.c
//-----------------------------------------------------------------------------
short KeyPressed(void);
short GetUserInput(short inc_clock);
void WaitForMillis(unsigned short);


//-----------------------------------------------------------------------------
// loadsave.c
//-----------------------------------------------------------------------------
short HandleLoad(short automatic,short load_problem);
short HandleSave(short automatic);
short LoadDefaults(void);
short SaveDefaults(void);
void LoadProblemDesc(void);
void HandleExport(void);


//-----------------------------------------------------------------------------
// menu.c
//-----------------------------------------------------------------------------
short MainMenu(short showmenu);
short PromotionDialog(void);


#endif


//#############################################################################
//###################### NO MORE FAKES BEYOND THIS LINE #######################
//#############################################################################
//
//=============================================================================
// Revision History
//=============================================================================
//
// $Log: routines.h,v $
// Revision 1.1  2002/02/11 16:34:23  tnussb
// initial version
//
//
